@@ -36,8 +36,9 @@ def parse_arguments():
     parser.add_argument("-refraction", default=None, type=str, help="Set to False to turn off refraction correction")
     parser.add_argument("-extension", default=None, type=str, help="Provide extension name so you can try different strategies")
     parser.add_argument("-ediff", default=None, type=str, help="ediff (degrees) default is 2")
-    parser.add_argument("-delTmax", default=None, type=float, help="max arc length (min) default is 75")
-#    parser.add_argument('-az_list', nargs="*",type=float,  help='azimuth min/max, e.g. 0 180  )')
+    parser.add_argument("-delTmax", default=None, type=float, help="max arc length (min) default is 75. Shorten for tides.")
+    parser.add_argument('-azlist', nargs="*",type=float,  help='User defined azimuth zones, i.e. 0 90 90 180 would mean only the east. Must be an even number of values.')
+    parser.add_argument('-frlist', nargs="*",type=int,  help='User defined frequencies using our nomenclature.')
 
 
     args = parser.parse_args().__dict__
@@ -54,14 +55,15 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
               h1: float = 0.5, h2: float = 6.0, nr1: float = None, nr2: float = None,
               peak2noise: float = 2.7, ampl: float = 6.0, allfreq: bool = False,
               l1: bool = False, l2c: bool = False, xyz: bool = False, refraction: bool = True,
-              extension: str = None, ediff: float=2.0, delTmax: float=75.0  ):
+              extension: str = None, ediff: float=2.0, delTmax: float=75.0, azlist: float=[], frlist: float=[] ):
 
     """
+    Make a json file that describes the lomb scargle analysis strategy you will use in gnssrefl.
 
     Parameters
     ----------
-    station : string
-        4 or 9 character ID of the station.
+    station : str
+        4 character station ID.
 
     lat : float
         latitude in degrees.
@@ -72,10 +74,10 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     height : float
         ellipsoidal height in meters.
 
-    e1 : integer, optional
+    e1 : int, optional
         elevation angle lower limit in degrees. default is 5.
 
-    e2 : integer, optional
+    e2 : int, optional
         elevation angle upper limit in degrees. default is 25.
 
     h1 : float, optional
@@ -102,45 +104,47 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
         True requests all GNSS frequencies.
         default is False (defaults to use GPS frequencies).
 
-    l1 : boolean, optional
+    l1 : bool, optional
         set to True to use only GPS L1 frequency. default is False.
 
-    l2c : boolean, optional
+    l2c : bool, optional
         set to use only GPS L2C frequency. default is False.
 
-    xyz : boolean, optional
+    xyz : bool, optional
         set to True if using Cartesian coordinates instead of Lat/Long/Ht.
         default is False.
 
-    refraction : boolean, optional
+    refraction : bool, optional
         set to False to turn off refraction correction.
         default is True.
 
-    extension : string, optional
+    extension : str, optional
         provide extension name so you can try different strategies. 
         Results will then go into $REFL_CODE/YYYY/results/ssss/extension
         Default is None
 
-    az_list : list of floats
-        azimuth min and max (for now)
-        default is 0 to 360
-
     ediff : float
         quality control parameter (Degrees)
         default is 2
 
     delTmax : float
         maximum allowed arc length (minutes)
-        default is 75, appropriate for snow or soil moisture
-        should be shorter (30 minutes or so) for tidal regimes
+        default is 75, which is a bit long for tides
+
+    azlist : list of floats
+        lets the user set the azimuth regions, in degrees
+        each region must be < 100 degrees! e.g. 0 90 90 180 would be all the east
+        90 180 180 270 would be all the south
+
+    frlist : list of integers
+        avoids all the booleans - if you know the frequencies, enter them.
+        e.g. 1 2 or 1 20 5 or 1 20 101 102
 
     """
 
     # make sure environment variables exist
     g.check_environ_variables()
 
-    #print(az_list)
-
     ns = len(station)
     if ns != 4:
         print('station name must be four characters long. Exiting.')
@@ -148,6 +152,7 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
 
 # location of the site - does not have to be very good.  within 100 meters is fine
     query_unr = False
+# if you input lat and long as zero ...
     if lat + long == 0:
         print('Going to assume that you want to use the UNR database.')
         query_unr = True
@@ -196,6 +201,7 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     if not os.path.isdir(outputdir):
         subprocess.call(['mkdir', outputdir])
 
+    print('extension', extension)
     if extension is None:
         outputfile = outputdir + '/' + station + '.json'
     else:
@@ -215,11 +221,19 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     # azimuth regions in degrees (in pairs)
     # you can of course have more subdivisions here
     #if (az_list[0]) == 0 & (az_list[-1] == 360):
-    if True:
+
+    N = len(azlist)
+    if N == 0:
+        print('User did not provide an azimuth list')
         lsp['azval'] = [0, 90, 90, 180, 180, 270, 270, 360]
-    # leaving this so the notebooks are not broken
-    #else:
-    #    print('You have requested specific azimuth limits')
+    else:
+        if (N % 2) == 0:
+            lsp['azval'] = azlist
+        else:
+            print('Illegal azimuth inputs. Must be an even number of azimuth pairs.')
+            sys.exit()
+
+    # a version I was working on
     #    lsp['azval'] = g.make_azim_choices(az_list)
 
     # default frequencies to use - and their required amplitudes. The amplitudes are not set in stone
@@ -236,6 +250,13 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     if l2c is True:
         lsp['freqs'] = [20]
 
+    if len(frlist) == 0:
+        # this means you entered nothing
+        print('Using standard frequency choices.')
+    else:
+        print('Implementing user-provided frequency list.')
+        lsp['freqs'] = frlist
+
     # create a list with all values equal to reqA
     # but the length of the list depends on the length of the list of frequencies
     lsp['reqAmp'] = [reqA]*len(lsp['freqs'])
@@ -245,6 +266,9 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     # write new RH results  each time you run the code
     lsp['overwriteResults'] = True
 
+    # write new RH results  each time you run the code
+    #lsp['nooverwrite'] = False
+
     # if snr file does not exist, try to make one
     lsp['seekRinex'] = False
 
@@ -267,6 +291,8 @@ def make_json(station: str, lat: float, long: float, height: float, e1: int = 5,
     # how long can the arc be, in minutes
     lsp['delTmax'] = delTmax  
  
+    # gzip SNR files after running the code
+    lsp['gzip'] = False   
 
     print('writing out to:', outputfile)
     with open(outputfile, 'w+') as outfile:
