@@ -66,6 +66,12 @@ def NMEA2SNR(locdir, fname, snrfile, csnr):
     T = []; PRN = []; AZ = []; ELV = []; SNR = []
         
     for i_prn in prn_unique:
+        # the original code added 100 - but did not take into account the 
+        # satellite numbers have been shifted for glonass.
+        # also there is an illegal signal at satellite "48" 
+        # i do not know what that is, but i am ignoring it.
+        #if (i_prn > 32):
+        #    print(i_prn, 'looks like an illegal satellite number')
  #       print(i_prn)
         time = t[prn == i_prn];angle = elv[prn == i_prn];azimuth = az[prn == i_prn]
         Snr = snr[prn == i_prn];Prn = prn[prn == i_prn]
@@ -89,7 +95,14 @@ def NMEA2SNR(locdir, fname, snrfile, csnr):
     fout = open(snrfile, 'w')
     for i in range(len(T)):
         if (float(ELV[i]) >= emin) and (float(ELV[i]) <= emax):
-            fout.write("%2g %10.4f %10.4f %10g %4s %4s %7.2f %4s %4s\n" % (PRN[i], float(ELV[i]), float(AZ[i]), float(T[i]),'0', '0', float(SNR[i]),'0', '0')) 
+            if (PRN[i] > 100):
+                # names were translated incorrectly for Glonass records - so removing 65 from them all ;-)
+                p = float(PRN[i]) -65 + 1
+            else:
+                p = float(PRN[i])
+            # only allow glonass and correct GPS
+            if (p > 100) | (p < 33):
+                fout.write("%3g %10.4f %10.4f %10g %4s %4s %7.2f %4s %4s\n" % (p, float(ELV[i]), float(AZ[i]), float(T[i]),'0', '0', float(SNR[i]),'0', '0')) 
     fout.close()
     
 def read_nmea(fname):
@@ -127,7 +140,7 @@ def read_nmea(fname):
     t = []; prn = []; az = []; elv = []; snr = []
     for i, line in enumerate(lines):
     
-        if b"GPGGA" in line: #read GPGGA sentence: Global Positioning System Fix Data 
+        if b"GGA" in line: #read GPGGA sentence: Global Positioning System Fix Data 
             hr = int(line.decode("utf-8").split(",")[1][0:2])
             mn = int(line.decode("utf-8").split(",")[1][2:4])
             sc = float(line.decode("utf-8").split(",")[1][4:8])
@@ -135,8 +148,16 @@ def read_nmea(fname):
             if (i > 100 and t_sec == 0):                   #set t to 86400 for the midnight data
                 t_sec = 86400
 
-        elif b"GPGSV" in line:                             #read GPGSV sentence: GPS Satellites in view in this cycle   
+        elif b"GSV" in line:                             #read GPGSV sentence: GPS Satellites in view in this cycle   
         
+            if b"GPGSV" in line:
+                prn_offset = 0
+            elif b"GLGSV" in line:
+                prn_offset = 100
+            elif b"GAGSV" in line:
+                prn_offset = 200
+            elif b"BDGSV" in line:
+                prn_offset = 300
             sent = line.decode("utf-8").split(",")         #GPGSV sentence 
             ttl_ms = int(sent[1])                          #Total number of messages in the GPGSV sentence 
             ms = int(sent[2])                              #Message number 
@@ -144,7 +165,7 @@ def read_nmea(fname):
             if (len(sent) == 20):                          #Case 1: 4 sat in view in this sentence 
                 cnt = 0
                 for j in range(0,4):
-                    prn.append(sent[4+cnt]) #field 4,8,12,16 :  SV PRN number
+                    prn.append(str(prn_offset + int(sent[4+cnt]))) #field 4,8,12,16 :  SV PRN number
                     elv.append(sent[5+cnt]) #field 5,9,13,17 :  Elevation in degrees, 90 maximum
                     az.append(sent[6+cnt]) #field 6,10,14,18:  Azimuth in degrees
                     snr.append(sent[7+cnt].split("*")[0])  #field 7,11,15,19:  SNR, 00-99 dB (null when not tracking)
@@ -156,7 +177,7 @@ def read_nmea(fname):
             elif (len(sent) == 16):     #Case 2: 3 sat in view in this sentence    
                 cnt = 0
                 for j in range(0,3):
-                    prn.append(sent[4+cnt])               
+                    prn.append(str(prn_offset + int(sent[4+cnt])))               
                     elv.append(sent[5+cnt])             
                     az.append(sent[6+cnt])                
                     snr.append(sent[7+cnt].split("*")[0]) 
@@ -168,7 +189,7 @@ def read_nmea(fname):
             elif (len(sent) == 12):   #Case 3: 2 sat in view in this sentence    
                 cnt = 0
                 for j in range(0,2):
-                    prn.append(sent[4+cnt])              
+                    prn.append(str(prn_offset + int(sent[4+cnt])))              
                     elv.append(sent[5+cnt])                
                     az.append(sent[6+cnt])                 
                     snr.append(sent[7+cnt].split("*")[0]) 
@@ -180,7 +201,7 @@ def read_nmea(fname):
             elif (len(sent) == 8):  #Case 4: 1 sat in view in this sentence    
                 cnt = 0
                 for j in range(0,1):
-                    prn.append(sent[4+cnt])               
+                    prn.append(str(prn_offset + int(sent[4+cnt])))               
                     elv.append(sent[5+cnt])                
                     az.append(sent[6+cnt])                
                     snr.append(sent[7].split("*")[0])  
