@@ -18,7 +18,7 @@ import scipy.interpolate as interpolate
 from scipy.interpolate import interp1d
 import math
 
-def writeout_spline_outliers(tvd_bad,txtdir):
+def writeout_spline_outliers(tvd_bad,txtdir,residual):
     """
 
     Write splinefit outliers to a file. 
@@ -31,14 +31,22 @@ def writeout_spline_outliers(tvd_bad,txtdir):
     txtdir : str
         directory for the output, i.e. $REFL_CODE/FiLes/station
 
+    residual : numpy array
+        outlier in units of meters (!)
     """
     nr,nc=tvd_bad.shape
     if nr > 0:
         f = txtdir + '/outliers.spline.txt'
-        print('Outliers written to: ', f)
+        print(nr, ' Outliers written to: ', f)
         fout = open(f, 'w+')
+        # put in a header
+        fout.write('{0:3s} sat azim deltT-min outlier-m fracDOY MJD\n'.format('%'))
+        fout.write('{0:3s} (1) (2)   (3)        (4)      (5)    (6) D\n'.format('%'))
         for w in range(0,nr):
-            fout.write('sat {0:3.0f} azim {1:7.2f} delta {2:7.2f} \n'.format( tvd_bad[w,3], tvd_bad[w,5], tvd_bad[w,14]))
+            fy = tvd_bad[w,1] + tvd_bad[w,4]/24 # fractional day of year
+            deltaT = tvd_bad[w,14]
+            mjd = tvd_bad[w,15]
+            fout.write('{0:3.0f} {1:7.2f} {2:7.2f} {3:7.2f} {4:9.3f} {5:15.7f} \n'.format( tvd_bad[w,3], tvd_bad[w,5], deltaT,residual[w],fy,mjd ))
         fout.close()
 
     return
@@ -259,7 +267,7 @@ def write_subdaily(outfile,station,ntv,writecsv,extraline,**kwargs):
     fout.close()
 
 
-def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim1,azim2,ampl,peak2noise,txtfile,h1,h2,kplt,txtdir):
+def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim1,azim2,ampl,peak2noise,txtfile,h1,h2,kplt,txtdir,default_usage):
     """
     reads in RH results and makes various plots to help users assess the quality of the solution
 
@@ -299,6 +307,9 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
         special plot made 
     txtdir : str
         directory where the results will be written
+    default_usage : bool
+        flat as to whether you are using this code for subdaily or for rh_plot.
+        this changes the plots a bit.
 
     Returns
     -------
@@ -407,35 +418,23 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
 
     ii = (np.absolute(residuals) > sigma) # data you like
     jj = (np.absolute(residuals) < sigma) # data you do not like ;-)
-    if plt2screen:
-        fig,ax=plt.subplots()
-        ax.plot(tval,nval,'ko',label='Total',markersize=3)
-        if (np.sum(Gval) > 0):
-            ax.plot(tval,Gval,'bo',label='GPS',markersize=3)
-        if (np.sum(Rval) > 0):
-            ax.plot(tval,Rval,'ro',label='GLO',markersize=3)
-        if (np.sum(Eval) > 0):
-            ax.plot(tval,Eval,'o',color='orange',label='GAL',markersize=3)
-        if (np.sum(Cval) > 0):
-            ax.plot(tval,Cval,'co',label='BEI',markersize=3)
-        plt.legend(loc="upper left")
-        plt.title(station + ': number of RH retrievals each day',fontsize=fs)
-        plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
-        plt.grid()
-        fig.autofmt_xdate()
-        plotname = txtdir + '/' + station + '_Subnvals.png'
-        plt.savefig(plotname,dpi=300)
-        print('png file saved as: ', plotname)
 
+    if plt2screen:
 
         minAz = float(np.min(tv[:,5])) ; maxAz = float(np.max(tv[:,5]))
 
-        two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2)
-        stack_two_more(otimes,tv,ii,jj,stats, station, txtdir,sigma,kplt)
+        if default_usage:
+            numsats_plot(station,tval,nval,Gval,Rval,Eval,Cval,txtdir,fs)
+            two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2)
+            stack_two_more(otimes,tv,ii,jj,stats, station, txtdir,sigma,kplt)
+            print_badpoints(tv[ii,:],residuals[ii],txtdir)
+        else:
+            # make both plots cause life is short
+            rh_plots(otimes,tv,station,txtdir,year,d1,d2,True)
+            rh_plots(otimes,tv,station,txtdir,year,d1,d2,False)
+
         plt.show()
 
-    # this might work... and then again, it might not
-    print_badpoints(tv[ii,:],residuals[ii],txtdir)
 
     # now write things out - using txtdir variable sent 
     if writecsv: 
@@ -450,12 +449,15 @@ def readin_and_plot(station, year,d1,d2,plt2screen,extension,sigma,writecsv,azim
     editedtv = tv[jj,:]
     nr,nc = editedtv.shape
 
+    # write out the initial timeseries which are basically the concatenated values for multiple days
     write_subdaily(fname,station,tvoriginal,writecsv,extraline)
-    print('Edited observations',nr)
-    extraline = 'outliers removed/restrictions'
-    write_subdaily(fname_new,station,editedtv,writecsv,extraline)
-    NV = len(tvoriginal)
-    print('Percent of observations removed: ', round(100*(NV-nr)/NV,2))
+
+    if default_usage:
+        print('Edited observations',nr)
+        extraline = 'outliers removed/restrictions'
+        write_subdaily(fname_new,station,editedtv,writecsv,extraline)
+        NV = len(tvoriginal)
+        print('Percent of observations removed: ', round(100*(NV-nr)/NV,2))
     
     # now return the names of the output files ... 
 
@@ -693,27 +695,23 @@ def writejsonfile(ntv,station, outfile):
 
 def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     """
+    This actually makes three stacked plots - not two, LOL
+    It gives an overview for quality control
 
     Parameters
     ----------
     otimes : numpy array of datetime objects
         observations times
-
     tv : numpy array
         gnssrefl results written into this variable using loadtxt
-
     station : str
         station name, only used for the title
-
     txtdir : str
         where the plots will be written to
-
     year: int
         what year is being analyzed
-
     d1 : int
         minimum day of year
-
     d2 : int
         maximum day of year
 
@@ -735,8 +733,8 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
     colors = tv[:,10]
     scatter = ax1.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
     colorbar = fig.colorbar(scatter, ax=ax1)
-    colorbar.set_label('Sat Numbers', fontsize=fs)
-    ax1.set_title('Constellation',fontsize=fs)
+    colorbar.set_label('Frequency', fontsize=fs)
+    ax1.set_title('Signals',fontsize=fs)
     plt.xticks(rotation =45,fontsize=fs); 
     ax1.set_ylabel('meters',fontsize=fs)
     plt.yticks(fontsize=fs)
@@ -747,8 +745,6 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
         ax1.set_xlim((th1, th2))
     fig.autofmt_xdate()
 
-
-
     #fig,(ax1,ax2)=plt.subplots(2,1,sharex=True)
         # put some azimuth information on it
     colors = tv[:,5]
@@ -789,6 +785,7 @@ def two_stacked_plots(otimes,tv,station,txtdir,year,d1,d2):
 
 def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     """
+    makes a plot of the reflector heights before and after minimal editing
 
     Parameters
     ----------
@@ -846,7 +843,7 @@ def stack_two_more(otimes,tv,ii,jj,stats, station, txtdir, sigma,kplt):
     plt.xticks(rotation =45,fontsize=8); plt.yticks(fontsize=8)
     plt.title('Edited Reflector Heights', fontsize=8)
     plt.grid() ; fig.autofmt_xdate()
-    plotname = txtdir + '/' + station + '_outliers_hunting.png'
+    plotname = txtdir + '/' + station + '_outliers.png'
     plt.savefig(plotname,dpi=300)
     plt.ylim((savey1, savey2))
     print('png file saved as: ', plotname)
@@ -1271,7 +1268,11 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
 
     tvd_bad = tvd[np.abs(residual_after) >  3*sigmaAfter, :]
-    writeout_spline_outliers(tvd_bad,txtdir)
+
+
+    kk = np.abs(residual_after) > 3*sigmaAfter
+    tvd_confused = tvd[kk,:]
+    writeout_spline_outliers(tvd_confused,txtdir,residual_after[kk])
 
     # keep values within 3 sigma 
     ii = np.abs(residual_after) < 3*sigmaAfter
@@ -1458,3 +1459,182 @@ def rhdot_correction2(station,fname,fname_new,pltit,outlierV,**kwargs):
 
     return tvd, correction
 
+
+def rh_plots(otimes,tv,station,txtdir,year,d1,d2,percent99):
+    """
+    overview plots for rh_plot
+
+    Parameters
+    ----------
+    otimes : numpy array of datetime objects
+        observations times
+    tv : numpy array
+        gnssrefl results written into this variable using loadtxt
+    station : str
+        station name, only used for the title
+    txtdir : str
+        where the plots will be written to
+    year: int
+        what year is being analyzed
+    d1 : int
+        minimum day of year
+    d2 : int
+        maximum day of year
+    percent99 : bool
+        whether you want only the 1-99 percentile plotted
+
+    """
+    if d1 == 1 and d2 == 366:
+        # these are the defaults
+        setlimits = False
+    else:
+        setlimits = True
+        yyy,mm,dd = g.ydoy2ymd(year, d1)
+        th1 = datetime.datetime(year=year, month=mm, day=dd)
+        yyy,mm,dd = g.ydoy2ymd(year, d2)
+        th2 = datetime.datetime(year=year, month=mm, day=dd)
+    # this is not working, so just setting it to false, cause who cares!
+    setlimits = False
+    fs = 10
+    fig,(ax2,ax3)=plt.subplots(2,1,sharex=True)
+        # put some azimuth information on it
+    colors = tv[:,5]
+        # ax.plot( otimes, tv[:,2], '.')
+        # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
+    # help from felipe nievinski
+    #tmp = numpy.percentile(tv[:,2], [1 99])
+    #matplotlib.pyplot.ylim(tmp[1], tmp[2])
+
+    scatter = ax2.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
+    colorbar = fig.colorbar(scatter, ax=ax2)
+    colorbar.set_label('deg', fontsize=fs)
+    ax2.set_ylabel('meters',fontsize=fs)
+    ax2.set_title('Azimuth',fontsize=fs)
+    #ax1.title.set_text('Azimuth')
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    fig.suptitle( station.upper() + ' Reflector Heights', fontsize=fs)
+
+    if setlimits:
+        ax2.set_xlim((th1, th2))
+
+    p1 = 0.01; p2 = 0.99
+    lowv, highv = my_percentile(tv[:,2],p1, p2)
+    print(lowv,highv)
+    # get the 1-99 percentile 
+    # this crashed my docker build
+#    yl = np.percentile(tv[:,2] ,[1 ,99])
+    if percent99:
+        ax2.set_ylim((lowv,highv))
+    ax2.invert_yaxis()
+    ax2.grid(True)
+
+    fig.autofmt_xdate()
+
+# put some amplitude information on it
+    # https://matplotlib.org/stable/gallery/lines_bars_and_markers/scatter_with_legend.html
+    colors = tv[:,6]
+
+    scatter = ax3.scatter(otimes,tv[:,2],marker='o', s=10, c=colors)
+    colorbar = fig.colorbar(scatter, ax=ax3)
+    ax3.set_ylabel('meters',fontsize=fs)
+    colorbar.set_label('v/v', fontsize=fs)
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    ax3.set_title('Amplitude',fontsize=fs)
+    ax3.grid(True)
+    if setlimits:
+        ax3.set_xlim((th1, th2))
+
+    if percent99:
+        ax3.set_ylim((lowv, highv ))
+    ax3.invert_yaxis()
+    fig.autofmt_xdate()
+
+    if percent99:
+        plotname = txtdir + '/' + station + '_rh2_99.png'
+    else:
+        plotname = txtdir + '/' + station + '_rh2.png'
+
+    print('png file saved as: ', plotname)
+    plt.savefig(plotname,dpi=150)
+
+def my_percentile(rh,p1, p2):
+    """
+    numpy percentile was crashing docker build
+    this is a quick work around
+
+    Parameters
+    ----------
+    rh : numpy array
+        reflector heights, but could be anything really
+    p1 : float
+        low percentage (from 0-1)
+    p2 : float
+        high percentage (from 0-1)
+
+    Returns
+    -------
+    low : float
+        low value (using input percentile)
+    highv : float
+        high value (using input percentile)
+
+    """
+
+    sorted_rh = np.sort(rh)
+    N = len(sorted_rh)
+    N1 = int(np.round(p1*N))
+    N2 = int(np.round(p2*N))
+
+    # calculate the low and high values at these percentiles
+    lowv = sorted_rh[N1] 
+    highv = sorted_rh[N2]
+
+    return  lowv, highv
+
+def numsats_plot(station,tval,nval,Gval,Rval,Eval,Cval,txtdir,fs):
+    """
+    makes the plot that summarizes the number of satellites in each
+    constellation per epoch
+
+    Parameters
+    ----------
+    station : str
+        name of the station
+    tval : numpy array
+        datetime objects?
+    nval : numpy array
+        number of total satellites at a given epoch
+    Gval : numpy array
+        number of galileo satellites at an epoch
+    Rval : numpy array
+        number of glonass satellites at an epoch
+    Eval : numpy array
+        number of galileo satellites at an epoch
+    Cval : numpy array
+        number of beidou satellites at an epoch
+    txtdir : str
+        where results are stored
+    fs : int
+        fontsize 
+
+    """
+
+    fig,ax=plt.subplots()
+    ax.plot(tval,nval,'ko',label='Total',markersize=3)
+    if (np.sum(Gval) > 0):
+        ax.plot(tval,Gval,'bo',label='GPS',markersize=3)
+    if (np.sum(Rval) > 0):
+        ax.plot(tval,Rval,'ro',label='GLO',markersize=3)
+    if (np.sum(Eval) > 0):
+        ax.plot(tval,Eval,'o',color='orange',label='GAL',markersize=3)
+    if (np.sum(Cval) > 0):
+        ax.plot(tval,Cval,'co',label='BEI',markersize=3)
+    plt.legend(loc="upper left")
+    plt.title(station + ': number of RH retrievals each day',fontsize=fs)
+    plt.xticks(rotation =45,fontsize=fs); plt.yticks(fontsize=fs)
+    plt.grid()
+    fig.autofmt_xdate()
+    plotname = txtdir + '/' + station + '_Subnvals.png'
+    plt.savefig(plotname,dpi=150)
+    print('png file saved as: ', plotname)
+
